/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { Capabilities } from '../../helpers';
import { shallow } from '../../utils/shallow-renderer';
import { TableFilters } from '../../utils/table-filters';

import { TasksView } from './tasks-view';

describe('TasksView', () => {
  it('matches snapshot', () => {
    const taskView = shallow(
      <TasksView
        filters={TableFilters.empty()}
        onFiltersChange={() => {}}
        openTaskDialog={undefined}
        goToView={() => {}}
        goToQuery={() => {}}
        goToClassicBatchDataLoader={() => {}}
        capabilities={Capabilities.FULL}
      />,
    );
    expect(taskView).toMatchSnapshot();
  });
});
